# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)
""" List of Odoo official addons which are not released as individual packages.
They are therefore considered as installed as soon as the 'odoo' dependency
is satisfied. """

odoo8 = {
    'base',
    'account',
    'account_accountant',
    'account_analytic_analysis',
    'account_analytic_default',
    'account_analytic_plans',
    'account_anglo_saxon',
    'account_asset',
    'account_bank_statement_extensions',
    'account_budget',
    'account_cancel',
    'account_chart',
    'account_check_writing',
    'account_followup',
    'account_payment',
    'account_sequence',
    'account_test',
    'account_voucher',
    'analytic',
    'analytic_contract_hr_expense',
    'analytic_user_function',
    'anonymization',
    'association',
    'auth_crypt',
    'auth_ldap',
    'auth_oauth',
    'auth_openid',
    'auth_signup',
    'base_action_rule',
    'base_gengo',
    'base_geolocalize',
    'base_iban',
    'base_import',
    'base_import_module',
    'base_report_designer',
    'base_setup',
    'base_vat',
    'board',
    'bus',
    'calendar',
    'claim_from_delivery',
    'contacts',
    'crm',
    'crm_claim',
    'crm_helpdesk',
    'crm_mass_mailing',
    'crm_partner_assign',
    'crm_profiling',
    'crm_project_issue',
    'decimal_precision',
    'delivery',
    'document',
    'edi',
    'email_template',
    'event',
    'event_sale',
    'fetchmail',
    'fleet',
    'gamification',
    'gamification_sale_crm',
    'google_account',
    'google_calendar',
    'google_drive',
    'google_spreadsheet',
    'hr',
    'hr_applicant_document',
    'hr_attendance',
    'hr_contract',
    'hr_evaluation',
    'hr_expense',
    'hr_gamification',
    'hr_holidays',
    'hr_payroll',
    'hr_payroll_account',
    'hr_recruitment',
    'hr_timesheet',
    'hr_timesheet_invoice',
    'hr_timesheet_sheet',
    'hw_escpos',
    'hw_posbox_homepage',
    'hw_posbox_upgrade',
    'hw_proxy',
    'hw_scale',
    'hw_scanner',
    'im_chat',
    'im_livechat',
    'im_odoo_support',
    'knowledge',
    'l10n_ae',
    'l10n_ar',
    'l10n_at',
    'l10n_be',
    'l10n_be_coda',
    'l10n_be_hr_payroll',
    'l10n_be_hr_payroll_account',
    'l10n_be_intrastat',
    'l10n_be_invoice_bba',
    'l10n_bo',
    'l10n_br',
    'l10n_ca',
    'l10n_ch',
    'l10n_cl',
    'l10n_cn',
    'l10n_co',
    'l10n_cr',
    'l10n_de',
    'l10n_do',
    'l10n_ec',
    'l10n_es',
    'l10n_et',
    'l10n_eu_service',
    'l10n_fr',
    'l10n_fr_hr_payroll',
    'l10n_fr_rib',
    'l10n_gr',
    'l10n_gt',
    'l10n_hn',
    'l10n_hr',
    'l10n_hu',
    'l10n_in',
    'l10n_in_hr_payroll',
    'l10n_it',
    'l10n_jp',
    'l10n_lu',
    'l10n_ma',
    'l10n_multilang',
    'l10n_mx',
    'l10n_nl',
    'l10n_no',
    'l10n_pa',
    'l10n_pe',
    'l10n_pl',
    'l10n_pt',
    'l10n_ro',
    'l10n_sa',
    'l10n_sg',
    'l10n_si',
    'l10n_syscohada',
    'l10n_th',
    'l10n_tr',
    'l10n_uk',
    'l10n_us',
    'l10n_uy',
    'l10n_ve',
    'l10n_vn',
    'lunch',
    'mail',
    'marketing',
    'marketing_campaign',
    'marketing_campaign_crm_demo',
    'marketing_crm',
    'mass_mailing',
    'membership',
    'mrp',
    'mrp_byproduct',
    'mrp_operations',
    'mrp_repair',
    'multi_company',
    'note',
    'note_pad',
    'pad',
    'pad_project',
    'payment',
    'payment_adyen',
    'payment_authorize',
    'payment_buckaroo',
    'payment_ogone',
    'payment_paypal',
    'payment_sips',
    'payment_transfer',
    'point_of_sale',
    'portal',
    'portal_claim',
    'portal_gamification',
    'portal_project',
    'portal_project_issue',
    'portal_sale',
    'portal_stock',
    'pos_discount',
    'pos_restaurant',
    'procurement',
    'procurement_jit',
    'procurement_jit_stock',
    'product',
    'product_email_template',
    'product_expiry',
    'product_extended',
    'product_margin',
    'product_visible_discount',
    'project',
    'project_issue',
    'project_issue_sheet',
    'project_timesheet',
    'purchase',
    'purchase_analytic_plans',
    'purchase_double_validation',
    'purchase_requisition',
    'report',
    'report_intrastat',
    'report_webkit',
    'resource',
    'sale',
    'sale_analytic_plans',
    'sale_crm',
    'sale_journal',
    'sale_layout',
    'sale_margin',
    'sale_mrp',
    'sale_order_dates',
    'sale_service',
    'sale_stock',
    'sales_team',
    'share',
    'stock',
    'stock_account',
    'stock_dropshipping',
    'stock_invoice_directly',
    'stock_landed_costs',
    'stock_picking_wave',
    'subscription',
    'survey',
    'survey_crm',
    'warning',
    'web',
    'web_analytics',
    'web_api',
    'web_calendar',
    'web_diagram',
    'web_gantt',
    'web_graph',
    'web_kanban',
    'web_kanban_gauge',
    'web_kanban_sparkline',
    'web_linkedin',
    'web_tests',
    'web_tests_demo',
    'web_view_editor',
    'website',
    'website_blog',
    'website_certification',
    'website_crm',
    'website_crm_partner_assign',
    'website_customer',
    'website_event',
    'website_event_sale',
    'website_event_track',
    'website_forum',
    'website_forum_doc',
    'website_gengo',
    'website_google_map',
    'website_hr',
    'website_hr_recruitment',
    'website_instantclick',
    'website_livechat',
    'website_mail',
    'website_mail_group',
    'website_membership',
    'website_partner',
    'website_payment',
    'website_project',
    'website_quote',
    'website_report',
    'website_sale',
    'website_sale_delivery',
    'website_sale_options',
    'website_twitter',
}

odoo9c = {
    'base',
    'account',
    'account_accountant',
    'account_analytic_default',
    'account_asset',
    'account_bank_statement_import',
    'account_budget',
    'account_cancel',
    'account_check_printing',
    'account_tax_cash_basis',
    'account_tax_python',
    'account_test',
    'account_voucher',
    'analytic',
    'anonymization',
    'association',
    'auth_crypt',
    'auth_ldap',
    'auth_oauth',
    'auth_signup',
    'barcodes',
    'base_action_rule',
    'base_gengo',
    'base_geolocalize',
    'base_iban',
    'base_import',
    'base_import_module',
    'base_setup',
    'base_vat',
    'board',
    'bus',
    'calendar',
    'claim_from_delivery',
    'crm',
    'crm_claim',
    'crm_partner_assign',
    'crm_project_issue',
    'decimal_precision',
    'delivery',
    'document',
    'event',
    'event_sale',
    'fetchmail',
    'fleet',
    'gamification',
    'gamification_sale_crm',
    'google_account',
    'google_calendar',
    'google_drive',
    'google_spreadsheet',
    'hr',
    'hr_attendance',
    'hr_contract',
    'hr_equipment',
    'hr_expense',
    'hr_gamification',
    'hr_holidays',
    'hr_payroll',
    'hr_payroll_account',
    'hr_recruitment',
    'hr_timesheet',
    'hr_timesheet_sheet',
    'hw_escpos',
    'hw_posbox_homepage',
    'hw_posbox_upgrade',
    'hw_proxy',
    'hw_scale',
    'hw_scanner',
    'im_livechat',
    'im_odoo_support',
    'l10n_ae',
    'l10n_ar',
    'l10n_at',
    'l10n_au',
    'l10n_be',
    'l10n_be_hr_payroll',
    'l10n_be_hr_payroll_account',
    'l10n_be_intrastat',
    'l10n_be_invoice_bba',
    'l10n_bo',
    'l10n_br',
    'l10n_ca',
    'l10n_ch',
    'l10n_cl',
    'l10n_cn',
    'l10n_cn_small_business',
    'l10n_cn_standard',
    'l10n_co',
    'l10n_cr',
    'l10n_de',
    'l10n_de_skr03',
    'l10n_de_skr04',
    'l10n_do',
    'l10n_ec',
    'l10n_es',
    'l10n_et',
    'l10n_eu_service',
    'l10n_fr',
    'l10n_fr_hr_payroll',
    'l10n_generic_coa',
    'l10n_gr',
    'l10n_gt',
    'l10n_hn',
    'l10n_hr',
    'l10n_hu',
    'l10n_in',
    'l10n_in_hr_payroll',
    'l10n_it',
    'l10n_jp',
    'l10n_lu',
    'l10n_ma',
    'l10n_multilang',
    'l10n_mx',
    'l10n_nl',
    'l10n_no',
    'l10n_pa',
    'l10n_pe',
    'l10n_pl',
    'l10n_pt',
    'l10n_ro',
    'l10n_sa',
    'l10n_sg',
    'l10n_si',
    'l10n_syscohada',
    'l10n_th',
    'l10n_tr',
    'l10n_uk',
    'l10n_us',
    'l10n_uy',
    'l10n_ve',
    'l10n_vn',
    'link_tracker',
    'lunch',
    'mail',
    'mail_tip',
    'marketing',
    'marketing_campaign',
    'marketing_campaign_crm_demo',
    'mass_mailing',
    'membership',
    'mrp',
    'mrp_byproduct',
    'mrp_operations',
    'mrp_repair',
    'note',
    'note_pad',
    'pad',
    'pad_project',
    'payment',
    'payment_adyen',
    'payment_authorize',
    'payment_buckaroo',
    'payment_ogone',
    'payment_paypal',
    'payment_sips',
    'payment_transfer',
    'point_of_sale',
    'portal',
    'portal_gamification',
    'portal_sale',
    'portal_stock',
    'pos_cache',
    'pos_discount',
    'pos_mercury',
    'pos_reprint',
    'pos_restaurant',
    'procurement',
    'procurement_jit',
    'product',
    'product_email_template',
    'product_expiry',
    'product_extended',
    'product_margin',
    'product_uos',
    'product_visible_discount',
    'project',
    'project_issue',
    'project_issue_sheet',
    'project_timesheet',
    'purchase',
    'purchase_requisition',
    'rating',
    'rating_project',
    'rating_project_issue',
    'report',
    'report_intrastat',
    'report_webkit',
    'resource',
    'sale',
    'sale_crm',
    'sale_expense',
    'sale_layout',
    'sale_margin',
    'sale_mrp',
    'sale_order_dates',
    'sale_service',
    'sale_stock',
    'sale_timesheet',
    'sales_team',
    'stock',
    'stock_account',
    'stock_calendar',
    'stock_dropshipping',
    'stock_landed_costs',
    'stock_picking_wave',
    'subscription',
    'survey',
    'survey_crm',
    'theme_bootswatch',
    'theme_default',
    'utm',
    'warning',
    'web',
    'web_analytics',
    'web_calendar',
    'web_diagram',
    'web_editor',
    'web_kanban',
    'web_kanban_gauge',
    'web_planner',
    'web_settings_dashboard',
    'web_tip',
    'web_view_editor',
    'website',
    'website_blog',
    'website_crm',
    'website_crm_claim',
    'website_crm_partner_assign',
    'website_customer',
    'website_event',
    'website_event_questions',
    'website_event_sale',
    'website_event_track',
    'website_form',
    'website_forum',
    'website_forum_doc',
    'website_gengo',
    'website_google_map',
    'website_hr',
    'website_hr_recruitment',
    'website_issue',
    'website_links',
    'website_livechat',
    'website_mail',
    'website_mail_channel',
    'website_mass_mailing',
    'website_membership',
    'website_partner',
    'website_payment',
    'website_portal',
    'website_portal_sale',
    'website_project_issue',
    'website_project_issue_sheet',
    'website_quote',
    'website_rating_project_issue',
    'website_sale',
    'website_sale_delivery',
    'website_sale_digital',
    'website_sale_options',
    'website_sale_stock',
    'website_slides',
    'website_twitter',
}

odoo9e = {
    'account_bank_statement_import_ofx',
    'account_bank_statement_import_qif',
    'account_batch_deposit',
    'account_contract_dashboard',
    'account_deferred_revenue',
    'account_extension',
    'account_online_sync',
    'account_plaid',
    'account_reports',
    'account_reports_followup',
    'account_sepa',
    'account_yodlee',
    'crm_voip',
    'currency_rate_live',
    'delivery_dhl',
    'delivery_fedex',
    'delivery_temando',
    'delivery_ups',
    'delivery_usps',
    'hr_appraisal',
    'hr_holidays_gantt',
    'inter_company_rules',
    'l10n_ar_reports',
    'l10n_at_reports',
    'l10n_be_coda',
    'l10n_be_reports',
    'l10n_bo_reports',
    'l10n_br_reports',
    'l10n_ch_reports',
    'l10n_cl_reports',
    'l10n_co_reports',
    'l10n_de_skr03_reports',
    'l10n_de_skr04_reports',
    'l10n_do_reports',
    'l10n_es_reports',
    'l10n_et_reports',
    'l10n_fr_reports',
    'l10n_gr_reports',
    'l10n_hr_reports',
    'l10n_hu_reports',
    'l10n_in_reports',
    'l10n_jp_reports',
    'l10n_lu_reports',
    'l10n_ma_reports',
    'l10n_nl_reports',
    'l10n_no_reports',
    'l10n_pl_reports',
    'l10n_ro_reports',
    'l10n_sg_reports',
    'l10n_si_reports',
    'l10n_th_reports',
    'l10n_uk_reports',
    'l10n_us_check_printing',
    'l10n_uy_reports',
    'l10n_vn_reports',
    'mass_mailing_themes',
    'pos_loyalty',
    'print',
    'print_docsaway',
    'print_sale',
    'project_forecast',
    'project_timesheet_synchro',
    'sale_contract',
    'sale_contract_asset',
    'sale_ebay',
    'stock_barcode',
    'voip',
    'web',
    'web_gantt',
    'website_contract',
    'website_crm_score',
    'website_enterprise',
    'website_form_editor',
    'website_portal_followup',
    'website_sign',
    'website_version',
}

odoo9 = odoo9c | odoo9e
