# -*- coding: utf-8 -*-
# © 2015 ACSONE SA/NV
# License LGPLv3 (http://www.gnu.org/licenses/lgpl-3.0-standalone.html)

# map names of common python external dependencies in Odoo manifest files
# to actual python package names
EXTERNAL_DEPENDENCIES_MAP = {
    'Asterisk': 'py-Asterisk',
    'coda': 'pycoda',
    'cups': 'pycups',
    'dateutil': 'python-dateutil',
    'ldap': 'python-ldap',
    'serial': 'pyserial',
    'Crypto.Cipher.DES3': 'pycrypto',
}
