{
    'name': 'addon 2',
    'summary': 'addon 2 summary',
    'version': '8.0.1.0.1',
    'depends': [
        'addon1',
    ],
    'external_dependencies': {
        'python': [
            'dateutil',
        ],
    },
}
